@@ -911,7 +911,6 @@ class Manaba:
                     str(last_modified.find("a").next_sibling.string).strip()
                 )
             else:
-                # 最終更新 <a onclick="return manaba.userballoon('97279', event);" href="user_97279_profile">中山　智美</a> 2021-08-04  10:25
                 last_edited_str = last_modified.text.strip()
                 last_edited_author = re.sub(r"最終更新 (.+) ([0-9]{4}-[0-9]{2}-[0-9]{2} +[0-9]{2}:[0-9]{2})", r"\1",
                                             last_edited_str)
@@ -1209,10 +1208,15 @@ class Manaba:
                 raise ManabaInternalError(
                     "get_task_status return None (" + statuses[0].strip() + ")")
 
-            your_status = get_your_status(statuses[1].strip())
-            if your_status is None:
-                raise ManabaInternalError(
-                    "your_status return None (" + statuses[1].strip() + ")")
+            if "まだ提出は可能です" in statuses[1]:  # 未提出 & ※遅延として取り扱われますが、まだ提出は可能です。
+                your_status = ManabaTaskYourStatusFlag.UNSUBMITTED
+            else:
+                your_status = get_your_status(statuses[1].strip())
+                if your_status is None:
+                    your_status = get_your_status(statuses[2].strip())
+                    if your_status is None:
+                        raise ManabaInternalError(
+                            "your_status return None (" + statuses[1].strip() + " | " + statuses[2].strip() + ")")
 
             return ManabaTaskStatus(task_status, your_status)
 
